@@ -420,15 +420,13 @@ class Core:
         Core.canceled = False
 
     @classmethod
-    def storeSettings(cls):
+    def storeSettings(cls, dataDir=None):
         """Store settings/paths to directories as class variables"""
         from .__init__ import wd
         from .toolkit.ffmpeg import findFfmpeg
 
         cls.wd = wd
-        dataDir = QtCore.QStandardPaths.writableLocation(
-            QtCore.QStandardPaths.StandardLocation.AppConfigLocation
-        )
+        dataDir = cls.getConfigPath(dataDir)
         # Windows: C:/Users/<USER>/AppData/Local/audio-visualizer
         # macOS: ~/Library/Preferences/audio-visualizer
         # Linux: ~/.config/audio-visualizer
@@ -590,6 +588,15 @@ class Core:
             # lowest level must be explicitly set on the root Logger
             libLog.setLevel(0)
 
-
-# always store settings in class variables even if a Core object is not created
-Core.storeSettings()
+    @staticmethod
+    def getConfigPath(dataDir=None):
+        return (
+            os.path.join(
+                QtCore.QStandardPaths.writableLocation(
+                    QtCore.QStandardPaths.StandardLocation.AppConfigLocation
+                ),
+                "audio-visualizer",
+            )
+            if dataDir is None
+            else dataDir
+        )
